summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/parse/parse.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/parse/parse.c b/src/parse/parse.c
index d52a6c4..e5b9c84 100644
--- a/src/parse/parse.c
+++ b/src/parse/parse.c
@@ -2446,8 +2446,10 @@ css_error parseInlineStyle(css_parser *parser)
return transition(parser, to, subsequent);
}
case AfterISBody0:
- /* Emit remaining fake events to end the parse */
+ /* Clean up any remaining tokens */
+ unref_interned_strings_in_tokens(parser);
+ /* Emit remaining fake events to end the parse */
if (parser->event != NULL) {
/* 1) end ruleset */
parser->event(CSS_PARSER_END_RULESET, NULL,